%% Plot lines on map
% Present the compressor speed lines and map
% Curve fit to polynomial functions
% 26.01.2017, Njl Tengesdal

close all; % close all open figure windows if any

figprop; % run figure properties

% structure of datafileDDMM.mat:
%          sp17 - vector with speed line data, bolk length  = n
%               [0w 0psi
%               [1w 1psi...
%               [6iw 7i psi] % last to tuned data 
%          spd - vector with speed line data, zero data, bolk length = m
%               [0w 0psi
%               [1w 1psi...
%               [6iw 7i psi] % last to tuned data
%          spdf - ...., zero and negative data, bolk length = f
%               [0w 0psi
%               [1w 1psi...
%               [6iw 7i psi] % last to tuned data
%          map815 - vector with map data, surge choke efficiency
%               [08w 08psi, surge ( small line)
%               [09w 09psi... choke (65 perc.)
%               [10w  10psi   surge (66 line)
%               [15w 15psi]      70, 75, 76, 77 and 78 (15)


polyfit_speedlines; % Call polyfit script

% Print polyfit models for each speed, 3 desimals
syms w 
d = 2;
a1 = char(vpa(poly2sym(p75,w),d));
a12 = char(vpa(poly2sym(p95,w),d));
a13 = char(vpa(poly2sym(p115,w),d));
a14 = char(vpa(poly2sym(p135,w),d));
a15 = char(vpa(poly2sym(p155,w),d));
a16 = char(vpa(poly2sym(p175,w),d));
a17 = char(vpa(poly2sym(p195,w),d));
a16i = char(vpa(poly2sym(p175i,w),d));
a17i = char(vpa(poly2sym(p195i,w),d));


fprintf('POLYNOMIALS p(w) = p(1)w^3 + p(2)w^2 + p(3)w + p(4):\n\npsi_{75} = %s \npsi_{95} = %s \npsi_{115} = %s \npsi_{135} = %s \npsi_{155} = %s \npsi_{175} = %s \npsi_{195} = %s\n\n',a1,a12,a13,a14,a15,a16i,a17i)


% NOTE:
%       xi, mass flow, (1-7 speed, 8-15 s- ch- eff)
%       yi, PR
%       
%       2 first rows of 1-7 is negative and zero mass flow rates

%% Symbolic functions of polynomial from curvefit
    % third order polynomial, CHANGE IF USING HIGHER ORDER
    psi_75 = @(w) p75(1)*w.^3 + p75(2)*w.^2 + p75(3)*w + p75(4);
    psi_95 = @(w) p95(1)*w.^3 + p95(2)*w.^2 + p95(3)*w + p95(4);
    psi_115 = @(w) p115(1)*w.^3 + p115(2)*w.^2 + p115(3)*w + p115(4);
    psi_135 = @(w) p135(1)*w.^3 + p135(2)*w.^2 + p135(3)*w + p135(4);
    psi_155 = @(w) p155(1)*w.^3 + p155(2)*w.^2 + p155(3)*w + p155(4);
    psi_175 = @(w) p175(1)*w.^3 + p175(2)*w.^2 + p175(3)*w + p175(4);
    psi_195 = @(w) p195(1)*w.^3 + p195(2)*w.^2 + p195(3)*w + p195(4);
    % tuned lines
    psi_175i = @(w) p175i(1)*w.^3 + p175i(2)*w.^2 + p175i(3)*w + p175i(4);
    psi_195i = @(w) p195i(1)*w.^3 + p195i(2)*w.^2 + p195i(3)*w + p195i(4);
    % data set for plotting
    w1 = -0.05:0.005:x1(end);  % mass flow values
    w2 = -0.05:0.005:x2(end);
    w3 = -0.05:0.005:x3(end);
    w4 = -0.05:0.005:x4(end);
    w5 = -0.05:0.005:x5(end);
    w6 = -0.05:0.005:x6(end);   w6i = -0.05:0.005:x6i(end); 
    w7 = -0.05:0.005:x7(end);   w7i = -0.05:0.005:x7i(end); 
    
%% FIGURE 1, PLOT COMPRESSOR MAP GT2252
%
% params plot
% c - deviation x dir
% d - deviation y dir
c = 0.01;
d = -0.05;
limit = -0.05;
dfit = 'k-'; % fit symbol and color
dpnt = 'k--'; % data point symbol and color, subplot1 (tot. map)
dpnt2 = 'k.'; % data point symbol and color, subplot2
%
figure(1); % create figure 1
ax1 = subplot(1,1,1);      % subplot with map and lines
% % Uncomment to print with data points w/ diamond
% data = plot(x1,y1,'kd','linewidth',0.8); 
% hold(ax1,'on');
% text(x1(end)+c,y1(end)+d,'N_{75}'); % text at end of line
% 
% plot(x2,y2,'kd','linewidth',0.8);
% text(x2(end)+c,y2(end)+d,'N_{95}');
% 
% plot(x3,y3,'kd','linewidth',0.8);
% text(x3(end)+c,y3(end)+d,'N_{115}');
% 
% plot(x4,y4,'kd','linewidth',0.8);
% text(x4(end)+c,y4(end)+d,'N_{135}');
% 
% plot(x5,y5,'kd','linewidth',0.8);
% text(x5(end)+c,y5(end)+d,'N_{155}');
% 
% %plot(x6,y6,'kd','linewidth',0.8);
% plot(x6i,y6i,'kd','linewidth',0.8);
% text(x6(end)+c,y6(end)+d,'N_{175}');
% 
% %plot(x7,y7,'kd','linewidth',0.8);
% plot(x7i,y7i,'kd','linewidth',0.8);
% text(x7(end)+c,y7(end)+d,'N_{75}');
% % uncomment fin.   
data = plot(x1(3:end),y1(3:end),dpnt,'linewidth',0.6); 
hold(ax1,'on');
text(x1(end)+c,y1(end)+d,'N_{75}'); % text at end of line

plot(x2(3:end),y2(3:end),dpnt,'linewidth',0.6);
text(x2(end)+c,y2(end)+d,'N_{95}');

plot(x3(3:end),y3(3:end),dpnt,'linewidth',0.6);
text(x3(end)+c,y3(end)+d,'N_{115}');

plot(x4(3:end),y4(3:end),dpnt,'linewidth',0.6);
text(x4(end)+c,y4(end)+d,'N_{135}');

plot(x5(3:end),y5(3:end),dpnt,'linewidth',0.6);
text(x5(end)+c,y5(end)+d,'N_{155}');

plot(x6(3:end),y6(3:end),dpnt,'linewidth',0.8);
%plot(x6i(4:end),y6i(4:end),dpnt,'linewidth',0.6);
text(x6(end)+c,y6(end)+d,'N_{175}');

plot(x7(3:end),y7(3:end),dpnt,'linewidth',0.8);
%plot(x7i(6:end),y7i(6:end),dpnt,'linewidth',0.6);
text(x7(end)+c,y7(end)+d,'N_{195}');

fit = plot(w1,psi_75(w1),dfit);   % plot polyfit
plot(w2,psi_95(w2),dfit)
plot(w3,psi_115(w3),dfit)
plot(w4,psi_135(w4),dfit)
plot(w5,psi_155(w5),dfit)
%plot(w6,psi_175(w6),dfit)
%plot(w7,psi_195(w7),dfit)
plot(w6i,psi_175i(w6i),dfit)
plot(w7i,psi_195i(w7i),dfit)

%plot(x8,fS1,'r-') %plot surge line
surge=plot(x10,y10,'b.-','linewidth',0.6);

%fit=plot(x9,fCh,'r-'); %plot choke line
choke=plot(x9,y9,'b-','linewidth',0.6);

% bolks of 30 data points, 08,    09,   10,     11,    12,     13, 
%                         1-30, 31-60, 61-90, 91-120, 121-150, 151,180
%                          14,       15
%                         181-210,  211,240
line70=plot(map815(91:120,1),map815(91:120,2),'k:','LineWidth',0.5); %70ef
line78=plot(map815(211:240,1),map815(211:240,2),'k:','LineWidth',0.5); %78ef


hold(ax1,'off') % End of plot
axis([limit  0.3  1  3.5])   %[xmin,xmax,ymin,ymax]
ax = gca; % current axes
%ax.FontSize = 10;
%ax.YTick = 1:0.2:3.5; ax.XTick = -0.06:0.04:0.3;
%ax.TickDir = 'out';
%ax.TickLength = [0.02 0.02];
%ax.YLim = [-2 2];
title('Compressor map GT2252 with fitted curves');
xlabel 'Mass flow [kg/s]'
ylabel 'Pressure ratio [-]'
legend([data fit surge choke line70 line78],'Data rpm','Fit',...
    'Stability line','Choke line','Eff. 70%','Eff. 78%',...
    'location','northeast');
%grid on
%print('fig1_originaldata','-depsc2','-r300');
%print('fig1_tuneddata','-depsc2','-r300');

%% FIGURE 2, SPEED LINES

figure(2);
ax2 = subplot(1,1,1); %subplot 2 only speed lines
data = plot(x1,y1,dpnt2,'linewidth',0.8); 
hold(ax2,'on');
    text(x1(end)+c,y1(end)+d,'N_{75}'); % text at end of line
plot(x2,y2,dpnt2,'linewidth',0.8);
    text(x2(end)+c,y2(end)+d,'N_{95}');
plot(x3,y3,dpnt2,'linewidth',0.8);
    text(x3(end)+c,y3(end)+d,'N_{115}');
plot(x4,y4,dpnt2,'linewidth',0.8);
    text(x4(end)+c,y4(end)+d,'N_{135}');
plot(x5,y5,dpnt2,'linewidth',0.8);
    text(x5(end)+c,y5(end)+d,'N_{155}');
plot(x6,y6,dpnt2,'linewidth',0.8);
%plot(x6i,y6i,dpnt2,'linewidth',0.8);
    text(x6(end)+c,y6(end)+d,'N_{175}');
plot(x7,y7,dpnt2,'linewidth',0.8);
%plot(x7i,y7i,dpnt2,'linewidth',0.8);
    text(x7(end)+c,y7(end)+d,'N_{195}');

fit = plot(w1,psi_75(w1),dfit);    % plot polyfit
plot(w2,psi_95(w2),dfit)
plot(w3,psi_115(w3),dfit)
plot(w4,psi_135(w4),dfit)
plot(w5,psi_155(w5),dfit)
plot(w6,psi_175(w6),dfit)
plot(w7,psi_195(w7),dfit)
%plot(w6i,psi_175i(w6i),dfit)
%plot(w7i,psi_195i(w7i),dfit)

 hold(ax2,'off')
 axis([limit  0.3  1  3.5])
% ax = gca; % current axes
% ax.FontSize = 10;
% ax.YTick = 1:0.2:3.5; ax.XTick = -0.06:0.04:0.3;

 title('Speed lines, rpm 75-195k');
 xlabel 'Mass flow [kg/s]'
 ylabel 'Pressure ratio [-]'
 legend([data fit],'Data','Fit','location','southeast');

%print('fig2_originaldata','-depsc2','-r300');
%print('fig2_tuneddata','-depsc2','-r300');