function psic = psiC(x,xdata)

%PSIC First-Principle compressor model characterstic
%   In Modeling and Simulation for Automatic Control
%            Egeland in Gravdahl 2002

w = xdata(:,1); N = xdata(:,2); 
% Paramters for estimation:
%
%  x(1) - sigma * r2^2, stanitz slip factor 1 - 2/numblades
%       r2     - outer radii impeller,  m
%  x(2) - cot(beta2b)/rho1*A1*r2, 1/kg
%       beta2b - fixed blade angle impeller outlet blade, rad
%       rho1   - gas density at inlet,  kg/m^3
%       A1     - inducer area (impeller eye area), m^2
%       r2     - outer radii impeller,  m
%  x(3) - 0.5*r1^2, m^2
%       r1     - inducer radii, m
%  x(4) - alpha, incidence loss coefficient 1/kg
%  x(5) - kf, friction factor, m^2/kg^2
%  x(6) - 1/cp*T01, 1/(J/kg.K * K )
%       cp      - specific heat constant pressure,   m^2/(K s^2), J/kg*K
%       T01     - stagnation inlet temperature,     K
%  x(7) - kappa/kappa-1, ratio
%       kappa   - ratio of specfic heats, cp/cv

% conversion from RPM to omega
omega = N*2*pi/60;

mu = x(1)*(1 - x(2)*w./omega); % mu(phi)
dhc = mu.*omega.^2 - x(3)*(omega - x(4)*w).^2 - x(5)*w.^2;

   if dhc*x(6) < -1      % Test the product, if less then -1
        temp = 0;        % then imaginary pressure ratio
        psic = (1 + temp).^x(7);
   elseif dhc*x(6) >= -1
        temp = dhc*x(6);
        psic = (1 + temp).^x(7);
   else
       psic = (1 + dhc*x(6)).^x(7);
   end


%% Final check if there exist a imaginary output
%    if imag(psi) ~= 0
%        psic = (1 + temp*x(6)).^x(7); % return with 0 as min
%    else
%        psic = psi;
%    end
    
end

