% Data organizing, COMPRESSOR MAP
% GT2252, compressor map data
% 16.01.2017 N.T
% REV 3/2

% DATA:
% d001 - d007, 75 - 195k RPM lines
% d008, Stability line / surge line
% d009, Choke / 60% line
% d010 - d015, [66, 70, 78, 77, 76, 75]%
clear all; close all; clc
% load

load('mapData/mapData_gt2252.mat'); % CM DATA, format: dXXX 01-015
load('zeroPoints_gt2252.mat'); % Zero (valley) point values
load('mapData01/dataSpeed_gt2252.mat'); % ADJ CM DATA, 26/01, dsXXX 01-07
% Note: First 4 points of ds0061 and ds0071 is tuning points
%       - upd 3/2: USING the 4 first data points of ds0061 and 71

%% re-sample with equal amount of data points  
%  w/ equal step size
% Note: comment out two first lines to not adjust for curves
d006i = [ds0061(1:4,1) ds0061(1:4,2);d006(9:end,1) d006(9:end,2)]; %trim
d007i = [ds0071(1:4,1) ds0071(1:4,2);d007(4:end,1) d007(4:end,2)]; %trim
n = 10; % sampling number
sp1 = resampling(d001,n,'linear');
sp2 = resampling(d002,n,'linear');
sp3 = resampling(d003,n,'linear');
sp4 = resampling(d004,n,'linear');
sp5 = resampling(d005,n,'linear');
sp6i = resampling(d006i,n,'linear');sp6 = resampling(d006,n,'linear');
sp7i = resampling(d007i,n,'linear');sp7 = resampling(d007,n,'linear');
%plot(d006i(:,1), d006i(:,2), 'k--',sp6i(:,1), sp6i(:,2), 'ro')

nm = 30; % sampling number for map lines
su1 = resampling(d008,nm,'linear'); % surge line
ch1 = resampling(d009,nm,'linear'); % choke line
ef66 = resampling(d010,nm,'linear'); ef77 = resampling(d013,nm,'linear');
ef70 = resampling(d011,nm,'linear'); ef76 = resampling(d014,nm,'linear');
ef78 = resampling(d012,nm,'linear'); ef75 = resampling(d015,nm,'linear');

%% Scale the units to kg/s for x-axis
% 1lb - 1kg * 0.45359237
% min to sec /60
sc = 0.45359237/60;
sp17 = [sp1;sp2;sp3;sp4;sp5;sp6;sp7;sp6i;sp7i]; 
                            %collect all 10 sampled speed lines + tuned
sp17(:,1) = sp17(:,1)*sc;
map815 = [su1;ch1;ef66;ef70;ef75;ef76;ef77;ef78]; % collect map lines
map815(:,1) = map815(:,1)*sc; 

%% Expand data set with calculated valleypoints and negative mass flow
% 
spd = [d001_0; sp17(1:n*1,:); d002_0; sp17(n*(2-1)+1:n*2,:);...
       d003_0; sp17(n*(3-1)+1:n*3,:); d004_0; sp17(n*(4-1)+1:n*4,:);...
       d005_0; sp17(n*(5-1)+1:n*5,:); d006_0; sp17(n*(6-1)+1:n*6,:);...
       d007_0; sp17(n*(7-1)+1:n*7,:); d006_0; sp17(n*(8-1)+1:n*8,:);...
       d007_0; sp17(n*(9-1)+1:n*9,:) ]; % expand sp17 vector to spd

% spd, each data line contains now n + 1 data.

% psi0 = [N75_n   N95_n ..... N195_n];
psi_n = [1.4  1.65  1.9  2.15   2.4   2.65   3.2]'; % estimates (dx + 2.5)
% 1/3/2017 - changed psi_n(7) to fit with 195k speedline

limit = -0.05; % limit of x axis on plot and dataset
m = n + 1; % adding the extra row with valley point to dataset

spdf = [limit psi_n(1); spd(1:m*1,:);...      
        limit  psi_n(2); spd(m*(2-1)+1:m*2,:);...
        limit  psi_n(3); spd(m*(3-1)+1:m*3,:);...
        limit  psi_n(4); spd(m*(4-1)+1:m*4,:);...
        limit  psi_n(5); spd(m*(5-1)+1:m*5,:);...
        limit  psi_n(6); spd(m*(6-1)+1:m*6,:);...
        limit  psi_n(7); spd(m*(7-1)+1:m*7,:);...
        limit  psi_n(6); spd(m*(8-1)+1:m*8,:);... % tuned line
        limit  psi_n(7); spd(m*(9-1)+1:m*9,:)]; % tuned line
f = m + 1; % final count of how long each data set is

%          sp17 - vector with speed line data, bolk length  = n
%               [0w 0psi
%               [1w 1psi...
%               [7iw 7i psi] % last two rows is tuned data 
%          spd - vector with speed line data, zero data, bolk length = m
%               [0w 0psi
%               [1w 1psi...
%               [7iw 7i psi] % last two rows is tuned data
%          spdf - ...., zero and negative data, bolk length = f
%               [0w 0psi
%               [1w 1psi...
%               [6iw 6i psi] % last two rows is tuned data
%               [7iw 7i psi %
%          map815 - vector with map data, surge choke efficiency, length nm
%               [08w 08psi, surge ( small line)
%               [09w 09psi... choke (65 perc.)
%               [10w  10psi   surge (66 line)
%               [15w 15psi]      70, 75, 76, 77 and 78 (15)
%% END USER INPUT
prompt = 'Save file with data? Y/N: ';
str = input(prompt,'s');
if isempty(str)
    str = 'N';
end
if str == 'Y' || str == 'y'
    prompt = 'filename (filename.mat): ';
    str2 = input(prompt,'s');
    disp('Saving data to file...')
    % save coeff in one file
    filename = str2;
    save(filename,'sp17','spd',...
        'spdf','map815','n','m','f','nm'); % n,length each bolk sp17,
                                      % m, spd
                                      % f, spdf
                                      % nm, map data each bolk
end
